@@ -1,19 +1,8 @@
-/* *************************************************************************
- *  Copyright 2015 Jakob Gruber <jakob.gruber@gmail.com>                   *
- *                                                                         *
- *  This program is free software: you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation, either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *  You should have received a copy of the GNU General Public License      *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
- ************************************************************************* */
+/*
+    SPDX-FileCopyrightText: 2015 Jakob Gruber <jakob.gruber@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QRandomGenerator>
 #include <config.h>
@@ -44,7 +33,7 @@ public:
     IOHandlerNoHints(BoardMap *map, BoardState *state, ElapsedTime *timer) : IOHandler(map, state, timer) { }
 
 protected:
-    void setBox(int x, int y) Q_DECL_OVERRIDE;
+    void setBox(int x, int y) override;
 };
 
 
@@ -63,7 +52,7 @@ public:
     IOHandlerHints(BoardMap *map, BoardState *state, ElapsedTime *timer) : IOHandler(map, state, timer) { }
 
 protected:
-    void setBox(int x, int y) Q_DECL_OVERRIDE;
+    void setBox(int x, int y) override;
 };
 
 
@@ -163,7 +152,7 @@ bool Picmi::won() const {
 QPoint Picmi::undo() {
     QPoint coord = m_state->undo();
     m_streaks->update();
-    emit stateChanged();
+    Q_EMIT stateChanged();
     return coord;
 }
 
@@ -204,7 +193,7 @@ void Picmi::solve() {
     m_state->solve(m_map.data());
     m_streaks->update();
     endGame();
-    emit gameCompleted();
+    Q_EMIT gameCompleted();
 }
 
 KScoreDialog::FieldInfo Picmi::endGame() {
@@ -213,7 +202,7 @@ KScoreDialog::FieldInfo Picmi::endGame() {
     KScoreDialog::FieldInfo score;
     score[KScoreDialog::Score].setNum(m_timer.elapsedSecs());
     score[KScoreDialog::Time] = Time(m_timer.elapsedSecs()).toString();
-    score[KScoreDialog::Date] = m_timer.startDate().toString("dd MMM yyyy hh:mm");
+    score[KScoreDialog::Date] = m_timer.startDate().toString(QStringLiteral("dd MMM yyyy hh:mm"));
 
     return score;
 }
@@ -241,11 +230,11 @@ int Picmi::elapsedSecs() const {
 void Picmi::setState(int x, int y, Board::State state) {
     m_io_handler->set(x, y, state);
     m_streaks->update(x, y);
-    emit stateChanged();
+    Q_EMIT stateChanged();
     if (m_state->boxCount() == m_map->boxCount() && won()) {
         m_state->replace(Board::Nothing, Board::Cross);
-        emit gameCompleted();
-        emit gameWon();
+        Q_EMIT gameCompleted();
+        Q_EMIT gameWon();
     }
 }
 
